package com.akamai.sdk.sample;

import com.akamai.media.IPlayerEventsListener;
import com.akamai.media.VideoPlayerContainer;
import com.akamai.media.VideoPlayerView;
import com.akamai.ui.media.MediaPlayerController;
import com.akamai.utils.AMPConfig;
import com.akamai.utils.AMPConfigLoader;
import com.akamai.utils.AMPConfigLoader.ConfigLoaderListener;
import com.akamai.webvtt.captioner.CaptionComponent;

import android.os.Bundle;
import android.app.Activity;
import android.content.res.Configuration;
import android.util.Log;
import android.view.Menu;
import android.widget.FrameLayout.LayoutParams;
import android.widget.LinearLayout;
import android.widget.ProgressBar;
import android.widget.RelativeLayout;

// Sample application
// Implements:
// - Events management
// - Playback support for live and vod streams
// - Seeking support 
public class Activity_AMP_Config extends Activity implements ConfigLoaderListener, IPlayerEventsListener
{
    // Player Config
    private AMPConfigLoader mAMPConfigLoader;

    // Video Player container object
    private VideoPlayerContainer mVideoPlayerContainer;

    // Video Player object
    private VideoPlayerView mVideoPlayer;

    // Control bar component
    private MediaPlayerController mMediaPlayerController;

    // Progress bar control
    private ProgressBar mProgressBar;

    // Media Asset url
    private final String MEDIA_ASSET_URL = "http://projects.mediadev.edgesuite.net/customers/akamai/mdt-html5-core/premier/2.8.0.0000/resources/feeds/vod-feed.json";

    // Android SDK License
    private final String ANDROID_SDK_LICENSE = "A_kIa_0hoh3h8VAv48Tth0319miyPuAcWsryLA4heoPaCzk5KRRPN4T-4-WH8gwznUZxpFWGVKheXeltdq_VYQ==";

    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.video_player_layout);

        mProgressBar = (ProgressBar) findViewById(R.id.progressBar);

        setupVideoPlayerComponents();
    }

    private void setupVideoPlayerComponents()
    {
        mVideoPlayerContainer = (VideoPlayerContainer) findViewById(R.id.playerViewCtrl);
        mVideoPlayerContainer.setMode(VideoPlayerContainer.MODE_NATIVE_BASIC);

        mMediaPlayerController = (MediaPlayerController) findViewById(R.id.playerControls);

        mAMPConfigLoader = new AMPConfigLoader(this);
        mAMPConfigLoader.loadConfig("http://projects.mediadev.edgesuite.net/customers/akamai/mdt-html5-core/premier/2.8.0.0000/samples/samples.xml");
    }

    @Override
    public void configLoaded(AMPConfig config)
    {
        // For changing to work in hardware decoding mode
        mVideoPlayerContainer.loadConfig(config);

        mVideoPlayer = mVideoPlayerContainer.getVideoPlayer();
        mVideoPlayer.setLicense(ANDROID_SDK_LICENSE);
        mVideoPlayer.setAutoResume(true);

        mVideoPlayer.setProgressBarControl(mProgressBar);
        mVideoPlayer.setEventsListener(this);

        mVideoPlayer.playFeedFromUrl(MEDIA_ASSET_URL);


    }

    @Override
    public boolean onCreateOptionsMenu(Menu menu) {
        getMenuInflater().inflate(R.menu.main, menu);
        return true;
    }



    // Android SDK Events Handler
    @Override
    public boolean onPlayerEvent(int iInEventType) {
        // Just forward the received event to the UI events handler
        Log.d("Activity_AMP_Config", "Player event received: " + iInEventType);


        return true;
    }


    @Override
    public boolean onPlayerExtendedEvent(int iInEventType, int arg1, int arg2) {
        // TODO Auto-generated method stub
        return true;
    }
    // Android SDK Events Handler End


    @Override
    protected void onResume()
    {
        if(mVideoPlayer != null)
            mVideoPlayer.onResume();

        super.onResume();
    }

    @Override
    protected void onPause()
    {
        if(mVideoPlayer != null)
            mVideoPlayer.onPause();

        super.onPause();
    }


    @Override
    protected void onDestroy()
    {
        if(mVideoPlayer != null)
        {
            mVideoPlayer.stop();
            mVideoPlayer.onDestroy();
        }
        super.onDestroy();
    }

    @Override
    public void onConfigurationChanged(Configuration newConfig) {
        super.onConfigurationChanged(newConfig);

        // Checks the orientation of the screen
        if (newConfig.orientation == Configuration.ORIENTATION_LANDSCAPE)
        {
            //View t1 = (View)findViewById(R.id.textView1);
            //View t2 = (View)findViewById(R.id.textView2);
            //t1.setVisibility(View.GONE);
            //t2.setVisibility(View.GONE);

            RelativeLayout playerContainer = (RelativeLayout) findViewById(R.id.playerContainer);

            LinearLayout.LayoutParams params = new LinearLayout.LayoutParams(LayoutParams.FILL_PARENT, LayoutParams.FILL_PARENT);
            playerContainer.setLayoutParams(params);

            mMediaPlayerController.setCurrentFullScreenMode(MediaPlayerController.UI_MODE_NON_FULLSCREEN);

            mVideoPlayerContainer.requestLayout();
        }
        else if (newConfig.orientation == Configuration.ORIENTATION_PORTRAIT)
        {
            //View t1 = (View)findViewById(R.id.textView1);
            //View t2 = (View)findViewById(R.id.textView2);
            //t1.setVisibility(View.VISIBLE);
            //t2.setVisibility(View.VISIBLE);

            RelativeLayout playerContainer = (RelativeLayout) findViewById(R.id.playerContainer);
            LinearLayout.LayoutParams params = new LinearLayout.LayoutParams(LayoutParams.FILL_PARENT, getResources().getDimensionPixelSize(R.dimen.player_height));
            playerContainer.setLayoutParams(params);

            mMediaPlayerController.setCurrentFullScreenMode(MediaPlayerController.UI_MODE_FULLSCREEN);

            mVideoPlayerContainer.requestLayout();
        }
    }



}

	
